"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _withStyles2 = _interopRequireDefault(require("@material-ui/core/styles/withStyles"));

var _react = _interopRequireDefault(require("react"));

var _nprogress = _interopRequireDefault(require("nprogress"));

var _router = _interopRequireDefault(require("next/router"));

var _hoistNonReactStatics = _interopRequireDefault(require("hoist-non-react-statics"));

var _getDisplayName = _interopRequireDefault(require("../util/getDisplayName"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

// Disaply a progress bar between route transitions
_nprogress.default.configure({
  template: "\n    <div class=\"bar\" role=\"bar\">\n      <dt></dt>\n      <dd></dd>\n    </div>\n  "
});

_router.default.onRouteChangeStart = function () {
  _nprogress.default.start();
};

_router.default.onRouteChangeComplete = function () {
  _nprogress.default.done();
};

_router.default.onRouteChangeError = function () {
  _nprogress.default.done();
};

var styles = function styles(theme) {
  return {
    '@global': {
      '#nprogress': {
        pointerEvents: 'none',
        '& .bar': {
          position: 'fixed',
          background: theme.palette.type === 'light' ? theme.palette.common.black : theme.palette.common.white,
          borderRadius: 1,
          zIndex: theme.zIndex.tooltip,
          top: 0,
          left: 0,
          width: '100%',
          height: 2
        },
        '& dd, & dt': {
          position: 'absolute',
          top: 0,
          height: 2,
          boxShadow: "".concat(theme.palette.type === 'light' ? theme.palette.common.black : theme.palette.common.white, " 1px 0 6px 1px"),
          borderRadius: '100%',
          animation: 'nprogress-pulse 2s ease-out 0s infinite'
        },
        '& dd': {
          opacity: 0.6,
          width: 20,
          right: 0,
          clip: 'rect(-6px,22px,14px,10px)'
        },
        '& dt': {
          opacity: 0.6,
          width: 180,
          right: -80,
          clip: 'rect(-6px,90px,14px,-6px)'
        }
      },
      '@keyframes nprogress-pulse': {
        '30%': {
          opacity: 0.6
        },
        '60%': {
          opacity: 0
        },
        to: {
          opacity: 0.6
        }
      }
    }
  };
};
/**
 * inject nprogress with NextJs.Router
 */


var withProgressBar = function withProgressBar(BaseComponent) {
  var InjectProgressBar = function InjectProgressBar(props) {
    return _react.default.createElement(BaseComponent, props);
  }; // wrap displayName for easier debug


  InjectProgressBar.displayName = "withProgressBar(".concat((0, _getDisplayName.default)(BaseComponent), ")"); // hoist all static functions

  (0, _hoistNonReactStatics.default)(InjectProgressBar, BaseComponent);
  return (0, _withStyles2.default)(styles)(InjectProgressBar);
};

var _default = withProgressBar;
exports.default = _default;
module.exports = exports.default;